@@ -381,11 +381,11 @@ static Resultat trisoussections_algo(Liens *liens , Contenu *soussections)
 		{
 			Booleen test;
 			SECURISE(test_liens(liens,soussectiondestination-1,soussectiondestination,&test));
-			if(test==FAUX)
-				break;
-			SECURISE(echange_liens(liens,soussectiondestination-1,soussectiondestination));
-			SECURISE(echange_contenu(soussections,soussectiondestination-1,soussectiondestination));
-
+			if(test==VRAI)
+			{
+				SECURISE(echange_liens(liens,soussectiondestination-1,soussectiondestination));
+				SECURISE(echange_contenu(soussections,soussectiondestination-1,soussectiondestination));
+			}
 		}
 	}
 	FINZONESECURISEE
