@@ -515,6 +515,72 @@ Resultat idees_generiques_lecture(TRAVAIL(Idees) idees , TRAVAIL_SCALAIRE(Chaine
 	return RESULTAT_OK;
 }
 
+Resultat idees_recherche_type(TRAVAIL(Idees) idees , TRAVAIL_SCALAIRE(Chaine) reference , COREFERENCE_SCALAIRE(Booleen) correct , COREFERENCE_SCALAIRE(TypeIdee) typeidee)
+{
+	/* Recherche le type d'une ide en fonction de sa rfrence.
+	 * La priorit des types est IDEE_PRESENTE, IDEE_MANQUANTE et
+	 * IDEE_GENERIQUE.
+	 * Si la rfrence n'est pas trouve, le boolen correct est
+	 * mis a FAUX.
+	 * Renvoie RESULTAT_ERREUR si idees ou reference est NULL.
+	 */
+	STOCKAGE_SCALAIRE(Indice) indice;
+	DEBUTZONESECURISEE
+	if(S_T(idees)==NULL)
+		return RESULTAT_ERREUR;
+	if(S_T_(reference)==NULL)
+		return RESULTAT_ERREUR;
+	for(indice=0 ; T_S_(indice)<T_S_(CHAMP_STOCKAGE_(CHAMP(idees , idees) , taille)) ; T_S_(indice)++)
+	{
+		TRAVAIL_SCALAIRE(Chaine) referenceidee;
+		TRAVAIL(Flux) fluxreference;
+		SECURISE(commandeidea_lecture_reference(T_S(CHAMP_STOCKAGE_(ELEMENT_(CHAMP_STOCKAGE_(CHAMP(idees , idees) , idee) , T_S_(indice)) , commandeidea)),R_T(fluxreference)));
+		SECURISE(flux_texte(fluxreference,R_T_(referenceidee)));
+		if(strcmp((char*)(reference),(char*)(referenceidee))==T_S_(0))
+		{
+			free(S_T_(referenceidee));
+			T_R_(correct)=T_S_(VRAI);
+			T_R_(typeidee)=T_S_(IDEE_PRESENTE);
+			return RESULTAT_OK;
+		}
+		free(S_T_(referenceidee));
+	}
+	for(indice=0 ; T_S_(indice)<T_S_(CHAMP_STOCKAGE_(CHAMP(idees , manquantes) , taille)) ; T_S_(indice)++)
+	{
+		TRAVAIL_SCALAIRE(Chaine) referenceidee;
+		TRAVAIL(Flux) fluxreference;
+		SECURISE(commandemissing_lecture_reference(T_S(ELEMENT_(CHAMP_STOCKAGE_(CHAMP(idees , manquantes) , idee) , T_S_(indice))),R_T(fluxreference)));
+		SECURISE(flux_texte(fluxreference,R_T_(referenceidee)));
+		if(strcmp((char*)(reference),(char*)(referenceidee))==T_S_(0))
+		{
+			free(S_T_(referenceidee));
+			T_R_(correct)=T_S_(VRAI);
+			T_R_(typeidee)=T_S_(IDEE_MANQUANTE);
+			return RESULTAT_OK;
+		}
+		free(S_T_(referenceidee));
+	}
+	for(indice=0 ; T_S_(indice)<T_S_(CHAMP_STOCKAGE_(CHAMP(idees , generiques) , taille)) ; T_S_(indice)++)
+	{
+		TRAVAIL_SCALAIRE(Chaine) referenceidee;
+		TRAVAIL(Flux) fluxreference;
+		SECURISE(commandegeneric_lecture_reference(T_S(ELEMENT_(CHAMP_STOCKAGE_(CHAMP(idees , generiques) , idee) , T_S_(indice))),R_T(fluxreference)));
+		SECURISE(flux_texte(fluxreference,R_T_(referenceidee)));
+		if(strcmp((char*)(reference),(char*)(referenceidee))==T_S_(0))
+		{
+			free(S_T_(referenceidee));
+			T_R_(correct)=T_S_(VRAI);
+			T_R_(typeidee)=T_S_(IDEE_GENERIQUE);
+			return RESULTAT_OK;
+		}
+		free(S_T_(referenceidee));
+	}
+	T_R_(correct)=T_S_(FAUX);
+	FINZONESECURISEE
+	return RESULTAT_OK;
+}
+
+
 Resultat idees_copie(TRAVAIL(Idees) idees , TRAVAIL(Idees) copie)
 {
 	/* Ralise une copie d'une structure d'ides.
