@@ -174,6 +174,7 @@ Resultat sortie_initialisation(TRAVAIL(Sortie) sortie)
 	CHAMP(sortie , ideereference)=NULL;
 	CHAMP(sortie , ideetitre)=NULL;
 	CHAMP(sortie , ideetexte)=NULL;
+	CHAMP(sortie , typeidee)=IDEE_VIDE;
 	CHAMP(sortie , ideereferencesidee)=NULL;
 	CHAMP(sortie , referenceindice)=NULL;
 	CHAMP(sortie , referencereference)=NULL;
@@ -536,7 +537,7 @@ static Resultat sortie_remplacement_texte_dep(TRAVAIL(CommandeDep) commandedep ,
 	{
 		SECURISE(flux_texte(T_S(CHAMP_STOCKAGE(CHAMP(general , sortie) , ideereference)),R_T_(referenceidee)));
 		denomination=NULL;
-		SECURISE(arbreidees_recherche_reference(CHAMP_TRAVAIL(general , arbreidees),destinationtexte,C_S_(correct),T_S(denomination),R_T_(niveauhierarchique),referenceidee,R_T_(typereference)));
+		SECURISE(arbreidees_recherche_reference(CHAMP_TRAVAIL(general , arbreidees),destinationtexte,C_S_(correct),T_S(denomination),R_T_(niveauhierarchique),referenceidee,T_S_(CHAMP_STOCKAGE(CHAMP(general , sortie) , typeidee)),R_T_(typereference)));
 		free(S_T_(referenceidee));
 		if(T_S_(correct)==T_S_(FAUX))
 		{
@@ -817,6 +818,7 @@ static Resultat sortie_parcours_idees(TRAVAIL(ArbreIdees) arbreidees , TRAVAIL(G
 		return RESULTAT_OK;
 	SECURISE(arbreidees_lecture_denomination(arbreidees,R_T(denomination)));
 	SECURISE(denominationidee_lecture(denomination,R_T_(typeidee),R_T_(idideepresente),R_T_(indicemanquante),R_T_(referencegenerique),R_T_(reference)));
+	CHAMP_STOCKAGE(CHAMP(general , sortie) , typeidee)=S_T_(typeidee);
 	if(typeidee==T_S_(IDEE_VIDE))
 		return RESULTAT_ERREUR_DOMAINE;
 	if(S_T_(reference)==NULL)
@@ -945,6 +947,7 @@ static Resultat sortie_parcours_idees(TRAVAIL(ArbreIdees) arbreidees , TRAVAIL(G
 			}
 		}
 	}
+	CHAMP_STOCKAGE(CHAMP(general , sortie) , typeidee)=IDEE_VIDE;
 	SECURISE(arbreidees_lecture_nombresoussections(arbreidees,R_T_(nombresoussections)));
 	if(nombresoussections>T_S_(0))
 	{
@@ -1691,6 +1694,7 @@ Resultat sortie_copie(TRAVAIL(Sortie) sortie , TRAVAIL(Sortie) copie)
 	{
 		SECURISE(flux_copie(CHAMP_TRAVAIL(sortie , ideetexte),CHAMP_TRAVAIL(copie , ideetexte)));
 	}
+	CHAMP(copie , typeidee)=CHAMP(sortie , typeidee);
 	if(CHAMP(sortie , ideereferencesidee)!=NULL)
 	{
 		SECURISE(referencesidee_copie(CHAMP_TRAVAIL(sortie , ideereferencesidee),CHAMP_TRAVAIL(copie , ideereferencesidee)));
